StateObj

Struct StateObj 

pub struct StateObj<T> { /* private fields */ }
The object owned state, usually as the parameter of method handler.

Implementations

Source

impl<T> StateObj<T>

pub fn as_object(&self) -> &ZObj

Gets object.

pub fn as_mut_object(&mut self) -> &mut ZObj

Gets mutable object.

Source

impl<T: 'static> StateObj<T>

pub fn as_state(&self) -> &T

Gets inner state.

pub fn as_mut_state(&mut self) -> &mut T

Gets inner mutable state.

Methods from Deref<Target = ZObj>

pub fn as_ptr(&self) -> *const zend_object

Returns a raw pointer wrapped.

pub fn as_mut_ptr(&mut self) -> *mut zend_object

Returns a raw pointer wrapped.

pub unsafe fn as_state_obj<T>(&self) -> &StateObj<T>

Upgrade to state obj.

Safety

Should only call this method for the class of object defined by the extension created by phper, otherwise, memory problems will caused.

pub unsafe fn as_mut_state_obj<T>(&mut self) -> &mut StateObj<T>

Upgrade to mutable state obj.

Safety

Should only call this method for the class of object defined by the extension created by phper, otherwise, memory problems will caused.

pub fn handle(&self) -> u32

Get the inner handle of object.

pub fn get_class(&self) -> &ClassEntry

Get the class reference of object.

pub fn get_mut_class(&mut self) -> &mut ClassEntry

Get the mutable class reference of object.

pub fn get_property(&self, name: impl AsRef<str>) -> &ZVal

Get the property by name of object.

pub fn get_mut_property(&mut self, name: impl AsRef<str>) -> &mut ZVal

Get the mutable property by name of object.

pub fn set_property(&mut self, name: impl AsRef<str>, val: impl Into<ZVal>)

Set the property by name of object.

pub fn call( &mut self, method_name: &str, arguments: impl AsMut<[ZVal]>, ) -> Result<ZVal>

Call the object method by name.

Examples
use phper::{alloc::EBox, classes::ClassEntry, values::ZVal};

fn example() -> phper::Result<ZVal> {
    let mut memcached = ClassEntry::from_globals("Memcached")?.new_object(&mut [])?;
    memcached.call(
        "addServer",
        &mut [ZVal::from("127.0.0.1"), ZVal::from(11211)],
    )?;
    let r = memcached.call("get", &mut [ZVal::from("hello")])?;
    Ok(r)
}