ZString

Type Alias ZString 

pub type ZString = EBox<ZStr>;
An owned PHP string value.

ZString represents an owned PHP string (zend_string) allocated in the Zend Engine memory. It provides safe access to PHP string operations and automatically manages memory cleanup using reference counting.

Aliased Type

pub struct ZString { /* private fields */ }

Implementations

Source

impl ZString

pub fn new(s: impl AsRef<[u8]>) -> Self

Creates a new zend string from a container of bytes.

pub fn new_persistent(s: impl AsRef<[u8]>) -> Self

Creates a new persistent zend string from a container of bytes.