ExecuteData

Struct ExecuteData 

pub struct ExecuteData { /* private fields */ }
Wrapper of zend_execute_data.

Implementations

Source

impl ExecuteData

pub unsafe fn from_ptr<'a>(ptr: *const zend_execute_data) -> &'a Self

Wraps a raw pointer.

Safety

Create from raw pointer.

Panics

Panics if pointer is null.

pub unsafe fn try_from_ptr<'a>( ptr: *const zend_execute_data, ) -> Option<&'a Self>

Wraps a raw pointer, return None if pointer is null.

Safety

Create from raw pointer.

pub unsafe fn from_mut_ptr<'a>(ptr: *mut zend_execute_data) -> &'a mut Self

Wraps a raw pointer.

Safety

Create from raw pointer.

Panics

Panics if pointer is null.

pub unsafe fn try_from_mut_ptr<'a>( ptr: *mut zend_execute_data, ) -> Option<&'a mut Self>

Wraps a raw pointer, return None if pointer is null.

Safety

Create from raw pointer.

pub const fn as_ptr(&self) -> *const zend_execute_data

Returns a raw pointer wrapped.

pub fn as_mut_ptr(&mut self) -> *mut zend_execute_data

Returns a raw pointer wrapped.

pub fn common_num_args(&self) -> u32

Gets common arguments count.

pub fn common_required_num_args(&self) -> usize

Gets common required arguments count.

pub fn common_arg_info(&self) -> *mut zend_arg_info

Gets first common argument info.

pub fn num_args(&self) -> usize

Gets arguments count.

pub fn func(&self) -> &ZFunc

Gets associated function.

pub fn get_opline_lineno(&self) -> Option<u32>

Gets the current opline line number if available. This represents the line number in the source code where the current operation is being executed.

pub fn get_return_value(&self) -> Option<&ZVal>

Gets associated return value.

pub fn get_return_value_mut(&mut self) -> Option<&mut ZVal>

Gets mutable reference to associated return value.

pub fn get_return_value_mut_ptr(&mut self) -> *mut ZVal

Gets associated return value pointer.

pub fn get_return_value_ptr(&self) -> *const ZVal

Gets immutable pointer to associated return value.

pub fn get_this(&mut self) -> Option<&ZObj>

Gets associated $this object if exists.

pub fn get_this_mut(&mut self) -> Option<&mut ZObj>

Gets associated mutable $this object if exists.

pub fn get_called_scope(&mut self) -> Option<&ClassEntry>

Gets associated called scope if it exists

pub fn get_parameter(&self, index: usize) -> &ZVal

Gets parameter by index.

pub fn get_mut_parameter(&mut self, index: usize) -> &mut ZVal

Gets mutable parameter by index.