pub type ZString = EBox<ZStr>;
An owned PHP string value.
ZString represents an owned PHP string (zend_string) allocated in the Zend Engine memory. It provides safe access to PHP string operations and automatically manages memory cleanup using reference counting.
ZString
pub struct ZString { /* private fields */ }
Creates a new zend string from a container of bytes.
Creates a new persistent zend string from a container of bytes.
source
self
other
==
!=